@@ -243,6 +243,29 @@ class CreateAuditResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class CreateAuditTrackRequest(AbstractModel):
+    """CreateAuditTrack请求参数结构体
+
+    """
+
+
+class CreateAuditTrackResponse(AbstractModel):
+    """CreateAuditTrack返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
 class DeleteAuditRequest(AbstractModel):
     """DeleteAudit请求参数结构体
 
@@ -288,6 +311,29 @@ class DeleteAuditResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class DeleteAuditTrackRequest(AbstractModel):
+    """DeleteAuditTrack请求参数结构体
+
+    """
+
+
+class DeleteAuditTrackResponse(AbstractModel):
+    """DeleteAuditTrack返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
 class DescribeAuditRequest(AbstractModel):
     """DescribeAudit请求参数结构体
 
@@ -381,6 +427,29 @@ class DescribeAuditResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class DescribeAuditTracksRequest(AbstractModel):
+    """DescribeAuditTracks请求参数结构体
+
+    """
+
+
+class DescribeAuditTracksResponse(AbstractModel):
+    """DescribeAuditTracks返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
 class DescribeEventsRequest(AbstractModel):
     """DescribeEvents请求参数结构体
 
@@ -978,6 +1047,29 @@ class LookupAttribute(AbstractModel):
         
 
 
+class ModifyAuditTrackRequest(AbstractModel):
+    """ModifyAuditTrack请求参数结构体
+
+    """
+
+
+class ModifyAuditTrackResponse(AbstractModel):
+    """ModifyAuditTrack返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
 class Resource(AbstractModel):
     """资源类型
 
